@@ -10,6 +10,7 @@ import aiohttp
 import chromadb
 import httpx
 from chromadb.api import AsyncClientAPI
+from chromadb.api.models.AsyncCollection import AsyncCollection
 from chromadb.config import Settings
 from chromadb.utils import embedding_functions
 
@@ -44,7 +45,7 @@ async def wait_for_server(host, port, timeout=10):
             await asyncio.sleep(0.1)  # Wait before retrying
 
 
-def start_server(configs: Config):
+async def start_server(configs: Config):
     assert configs.host is not None
     assert configs.port is not None
     assert configs.db_path is not None
@@ -53,6 +54,8 @@ def start_server(configs: Config):
             f"Creating database at {os.path.expanduser('~/.local/share/vectorcode/chromadb/')}.",
             file=sys.stderr,
         )
+    env = os.environ.copy()
+    env.update({"ANONYMIZED_TELEMETRY": "False"})
     process = subprocess.Popen(
         [
             sys.executable,
@@ -71,8 +74,10 @@ def start_server(configs: Config):
         stdout=subprocess.DEVNULL,
         stderr=sys.stderr,
         preexec_fn=os.setsid,
+        env=env,
     )
-    asyncio.run(wait_for_server(configs.host, configs.port))
+
+    await wait_for_server(configs.host, configs.port)
     return process
 
 
@@ -81,14 +86,13 @@ def get_client(configs: Config) -> Coroutine[Any, Any, AsyncClientAPI]:
     assert configs.port is not None
     assert configs.db_path is not None
     try:
-        if configs.db_settings is not None:
-            setting = Settings(**configs.db_settings)
-        else:
-            setting = None
+        settings = {"anonymized_telemetry": False}
+        if isinstance(configs.db_settings, dict):
+            settings.update(configs.db_settings)
         return chromadb.AsyncHttpClient(
             host=configs.host or "localhost",
             port=configs.port or 8000,
-            settings=setting,
+            settings=Settings(**settings),
         )
     except ValueError:
         print(
@@ -143,7 +147,7 @@ async def make_or_get_collection(client: AsyncClientAPI, configs: Config):
     return collection
 
 
-def verify_ef(collection, configs: Config):
+def verify_ef(collection: AsyncCollection, configs: Config):
     collection_ef = collection.metadata.get("embedding_function")
     collection_ep = collection.metadata.get("embedding_params")
     if collection_ef and collection_ef != configs.embedding_function:
